@@ -1,13 +1,13 @@
 /*
  * VF_Ftype.c
  *
- * FreeType 1.1 compatible
+ * FreeType 1.2 compatible
  */
 
 
 /* This file is part of VFlib
  *
- * Copyright (C) 1995-1998 Hirotsugu KAKUGAWA.   All rights reserved.
+ * Copyright (C) 1995-1999 Hirotsugu KAKUGAWA.   All rights reserved.
  *
  * This file is part of the VFlib Library.  This library is free
  * software; you can redistribute it and/or modify it under the terms of
@@ -130,9 +130,9 @@ OpenFont(fobj)
   FontObj* fobj;
 {
   Font        *font;
-  TT_Face_Properties properties;
-  int charmapIndex;
-  short platformID, encodingID;
+  TT_Face_Properties  properties;
+  int  charmapIndex;
+  TT_UShort  platformID, encodingID;
 
   font = (Font*) fobj->Locals;
 
@@ -152,7 +152,7 @@ OpenFont(fobj)
     goto err;
   charmapIndex = TT_Get_CharMap_Count(font->face);
   while (--charmapIndex >= 0) {
-    if ((error = TT_Get_CharMap_ID(font->face, charmapIndex,
+    if ((error = TT_Get_CharMap_ID(font->face, (TT_UShort)charmapIndex,
 				   &platformID, &encodingID)))
       goto err;
     if (platformID == 3 && encodingID == 1) {  /* Unicode */
@@ -165,7 +165,8 @@ OpenFont(fobj)
     }
   }
   if (charmapIndex < 0) charmapIndex = 0;
-  if ((error = TT_Get_CharMap(font->face, charmapIndex, &(font->charMap))))
+  if ((error = TT_Get_CharMap(font->face,
+			      (TT_UShort)charmapIndex, &(font->charMap))))
     goto err;
 
   return 0;
@@ -218,7 +219,8 @@ GetBitmap(obj, jiscode, w, h, bw, bo, bm_buf)
   TT_Outline outline;
   TT_Matrix matrix;
   TT_Pos tx, ty;
-  int code, i, x, y;
+  TT_UShort code;
+  int i, x, y;
   unsigned char *src, *dst;
 
   font = (Font*) obj->Locals;
@@ -295,7 +297,7 @@ GetBitmap(obj, jiscode, w, h, bw, bo, bm_buf)
   for (y = 0; y < Bit.rows; y++) {
     src = Bit.bitmap;
     src += Bit.cols * y;
-    dst = bm_buf + bw * y; 
+    dst = (unsigned char*)bm_buf + bw * y; 
     for (x = 0; x < Bit.cols;) {
       dst[x] |= *src >> bo;
       if (++x >= w) break;
@@ -325,7 +327,8 @@ GetOutline(obj, jiscode)
   TT_Outline outline;
   TT_Matrix matrix;
   TT_Pos tx, ty;
-  int code, vfsize, ct, pt, sp, ep, p1, p2, p3, i;
+  TT_UShort code;
+  int vfsize, ct, pt, sp, ep, p1, p2, p3, i;
   double x1, y1, x2, y2, x3, y3;
   long token, *vfdata, *vfp;
 
