@@ -39,32 +39,32 @@
 #  define FAR
 #  define MALLOC malloc
 #endif
-typedef char int8;
-typedef unsigned char uint8;
-typedef short int16;
-typedef unsigned short uint16;
-typedef long int32;
-typedef unsigned long uint32;
+typedef char Int8;
+typedef unsigned char UInt8;
+typedef short Int16;
+typedef unsigned short UInt16;
+typedef long Int32;
+typedef unsigned long UInt32;
 typedef long Fixed;
 typedef short FUnit;
 typedef struct {
-	uint32 bc;
-	uint32 ad;
+	UInt32 bc;
+	UInt32 ad;
 } BigDate;
 
 /*
  *  .tti file header
  */
 typedef struct {
-	uint16 CodeTableOffset;			/* JIS -> Glyph Index table */
-	uint16 MaxJIS;					/* max value of JIS (ku) code */
-	uint16 unitsPerEm;				/* accuracy */
+	UInt16 CodeTableOffset;			/* JIS -> Glyph Index table */
+	UInt16 MaxJIS;					/* max value of JIS (ku) code */
+	UInt16 unitsPerEm;				/* accuracy */
 	FUnit xMin;						/* minimum x-data (origin) */
 	FUnit yMin;						/* minimum x-data (origin) */
-	uint16 maxPoints;				/* maximum number of points */
-	uint16 maxContours;				/* maximum number of contours */
-	uint32 IndexToLocBase;			/* Glyph Index -> Offset table */
-	uint32 GlyphBase;				/* Glyph data */
+	UInt16 maxPoints;				/* maximum number of points */
+	UInt16 maxContours;				/* maximum number of contours */
+	UInt32 IndexToLocBase;			/* Glyph Index -> Offset table */
+	UInt32 GlyphBase;				/* Glyph data */
 } TTI_HEADER;
 #define SIZE_OF_TTI_HEADER 22
 
@@ -72,18 +72,18 @@ typedef struct {
  *  Table Directory
  */
 typedef struct {
-	int32 version;					/* 0x10000 (1.0) */
-	uint16 numOffsets;				/* number of tables */
-	uint16 searchRange;				/* (max2 <= numOffsets)*16 */
-	uint16 entrySelector;			/* log2 (max2 <= numOffsets) */
-	uint16 rangeShift;				/* numOffsets*16-searchRange */
+	Int32 version;					/* 0x10000 (1.0) */
+	UInt16 numOffsets;				/* number of tables */
+	UInt16 searchRange;				/* (max2 <= numOffsets)*16 */
+	UInt16 entrySelector;			/* log2 (max2 <= numOffsets) */
+	UInt16 rangeShift;				/* numOffsets*16-searchRange */
 } sfnt_OffsetTable;
 
 typedef struct {
-	uint32 tag;
-	uint32 checkSum;
-	uint32 offset;
-	uint32 length;
+	UInt32 tag;
+	UInt32 checkSum;
+	UInt32 offset;
+	UInt32 length;
 } sfnt_DirectoryEntry;
 
 #define tag_CharToIndexMap		0x636d6170L		/* 'cmap' */
@@ -132,11 +132,11 @@ typedef struct {
 typedef struct {
 	Fixed version;					/* for this table set to 1.0 */
 	Fixed fontRevision;				/* For Font Manufacturer */
-	uint32 checkSumAdjustment;
-	uint32 magicNumber;				/* signature; should always be
+	UInt32 checkSumAdjustment;
+	UInt32 magicNumber;				/* signature; should always be
 									   0x5F0F3CF5  == MAGIC */
-	uint16 flags;
-	uint16 unitsPerEm;				/* Specifies how many Font Units
+	UInt16 flags;
+	UInt16 unitsPerEm;				/* Specifies how many Font Units
 									   we have per EM */
 
 	BigDate created;
@@ -149,18 +149,18 @@ typedef struct {
 	FUnit xMax;
 	FUnit yMax;
 
-	uint16 macStyle;				/* macintosh style word */
-	uint16 lowestRecPPEM;			/* lowest recommended # of pixels per Em */
+	UInt16 macStyle;				/* macintosh style word */
+	UInt16 lowestRecPPEM;			/* lowest recommended # of pixels per Em */
 
 	/*  0: fully mixed directional glyphs,
 	    1: only strongly L->R or T->B glyphs,
 	   -1: only strongly R->L or B->T glyphs,
 	    2: like 1 but also contains neutrals,
 	   -2: like -1 but also contains neutrals */
-	int16 fontDirectionHint;
+	Int16 fontDirectionHint;
 
-	int16 indexToLocFormat;
-	int16 glyphDataFormat;
+	Int16 indexToLocFormat;
+	Int16 glyphDataFormat;
 } sfnt_FontHeader;
 
 /*
@@ -169,24 +169,24 @@ typedef struct {
 
 typedef struct {
 	Fixed version;					/* for this table set to 1.0 */
-	uint16 numGlyphs;
-	uint16 maxPoints;				/* in an individual glyph */
-	uint16 maxContours;				/* in an individual glyph */
-	uint16 maxCompositePoints;		/* in a composite glyph */
-	uint16 maxCompositeContours;	/* in a composite glyph */
-	uint16 maxElements;				/* set to 2, or 1 if
+	UInt16 numGlyphs;
+	UInt16 maxPoints;				/* in an individual glyph */
+	UInt16 maxContours;				/* in an individual glyph */
+	UInt16 maxCompositePoints;		/* in a composite glyph */
+	UInt16 maxCompositeContours;	/* in a composite glyph */
+	UInt16 maxElements;				/* set to 2, or 1 if
 									   no twilightzone points */
-	uint16 maxTwilightPoints;		/* max points in element zero */
-	uint16 maxStorage;				/* max number of storage locations */
-	uint16 maxFunctionDefs;			/* max number of FDEFs in any preprogram */
-	uint16 maxInstructionDefs;		/* max number of IDEFs in any preprogram */
-	uint16 maxStackElements;		/* max number of stack elements for
+	UInt16 maxTwilightPoints;		/* max points in element zero */
+	UInt16 maxStorage;				/* max number of storage locations */
+	UInt16 maxFunctionDefs;			/* max number of FDEFs in any preprogram */
+	UInt16 maxInstructionDefs;		/* max number of IDEFs in any preprogram */
+	UInt16 maxStackElements;		/* max number of stack elements for
 									   any individual glyph */
-	uint16 maxSizeOfInstructions;	/* max size in bytes for
+	UInt16 maxSizeOfInstructions;	/* max size in bytes for
 									   any individual glyph */
-	uint16 maxComponentElements;	/* number of glyphs referenced
+	UInt16 maxComponentElements;	/* number of glyphs referenced
 									   at top level */
-	uint16 maxComponentDepth;		/* levels of recursion,
+	UInt16 maxComponentDepth;		/* levels of recursion,
 									   1 for simple components */
 } sfnt_maxProfileTable;
 
@@ -194,48 +194,48 @@ typedef struct {
  *  Char2Index structures, including platform IDs
  */
 typedef struct {
-	uint16  format;
-	uint16  length;
-	uint16  version;
+	UInt16  format;
+	UInt16  length;
+	UInt16  version;
 } sfnt_mappingTable;
 
 typedef struct {
-	uint16  platformID;
-	uint16  specificID;
-	uint32  offset;
+	UInt16  platformID;
+	UInt16  specificID;
+	UInt32  offset;
 } sfnt_platformEntry;
 
 typedef struct {
-	uint16  version;
-	uint16  numTables;
+	UInt16  version;
+	UInt16  numTables;
 	sfnt_platformEntry platform[1];	/* platform[numTables] */
 } sfnt_char2IndexDirectory;
 
 typedef struct {
-	uint16 segCountX2;				/* 2 x segCount */
-	uint16 searchRange;				/* 2 x (2**floor(log2(segCount))) */
-	uint16 entrySelector;			/* log2(searchRange/2) */
-	uint16 rangeShift;				/* 2 x segCount - searchRange */
-	uint16 FAR *endCount;
-	uint16 FAR *startCount;
-	uint16 FAR *idDelta;
-	uint16 FAR *idRangeOffset;
+	UInt16 segCountX2;				/* 2 x segCount */
+	UInt16 searchRange;				/* 2 x (2**floor(log2(segCount))) */
+	UInt16 entrySelector;			/* log2(searchRange/2) */
+	UInt16 rangeShift;				/* 2 x segCount - searchRange */
+	UInt16 FAR *endCount;
+	UInt16 FAR *startCount;
+	UInt16 FAR *idDelta;
+	UInt16 FAR *idRangeOffset;
 	long idRangeBase;
 } CharToIndexFormat4;
 
 typedef struct {
-    uint16 platformID;
-    uint16 specificID;
-    uint16 languageID;
-    uint16 nameID;
-    uint16 length;
-    uint16 offset;
+    UInt16 platformID;
+    UInt16 specificID;
+    UInt16 languageID;
+    UInt16 nameID;
+    UInt16 length;
+    UInt16 offset;
 } sfnt_NameRecord;
 
 typedef struct {
-    uint16 format;
-    uint16 count;
-    uint16 stringOffset;
+    UInt16 format;
+    UInt16 count;
+    UInt16 stringOffset;
 /*  sfnt_NameRecord[count]  */
 } sfnt_NamingTable;
 
@@ -247,7 +247,7 @@ typedef enum {
 } sfnt_PlatformEnum;
 
 /* JIS -> Unicode mapping table */
-uint16 UnicodeTbl[][94] = {
+UInt16 UnicodeTbl[][94] = {
 { /* category 01 */
 0x0000, 0x3001, 0x3002, 0xFF0C, 0xFF0E, 0x30FB, 0xFF1A, 0xFF1B,
 0xFF1F, 0xFF01, 0x309B, 0x309C, 0x00B4, 0xFF40, 0x00A8, 0xFF3E,
